
# Slot: addresses




URI: [ks:addresses](https://w3id.org/linkml/tests/kitchen_sink/addresses)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [Address](Address.md)

## Parents


## Children


## Used by

 * [Person](Person.md)
